Skip to contents

Attach the CourseKata course packages

Usage

coursekata_attach(do_not_ask = FALSE, quietly = FALSE)

Arguments

do_not_ask

Prevent asking the user to install missing packages (they are skipped).

quietly

Whether to suppress messages.

Value

A named logical vector indicating which packages were attached.

Examples

coursekata_attach()