Skip to contents

Install or update all CourseKata packages.

Usage

coursekata_install(...)

coursekata_update(...)

Arguments

...

Arguments passed on to remotes::install_cran or remotes::install_github depending on whether the package appears to be from CRAN or GitHub.

Value

The state of all the packages after any updates have been performed.