Create a function that provides a colorblind palette.
Source:R/theme.R
coursekata_palette_provider.RdCreate a function that provides a colorblind palette.
Value
A function that accepts one argument n, which is the number of colors you want to use
in the plot. This function is used by scales like scale_color_discrete to provide colorblind-
safe palettes. Where possible, the function will use the hand-picked colors from
coursekata_palette(), and when more colors are needed than are available, it will use the
viridisLite::viridis() palette.