R/coursekata_repos.R
coursekata_repos.Rd
Ensures a default CRAN is set if one is not already set.
coursekata_repos(repos = getOption("repos"))
Optionally set a repository character vector to augment.
A set of repositories that can be used to install or update the CourseKata packages.
coursekata_repos() #> RSPM #> "https://packagemanager.posit.co/cran/__linux__/noble/latest" #> CRAN #> "https://cran.rstudio.com"