Test the fit of a model on a train and test set.
Arguments
- model
An
lmmodel.- df_train
A data frame with the training data.
- df_test
A data frame with the test data.
Test the fit of a model on a train and test set.
An lm model.
A data frame with the training data.
A data frame with the test data.