Arguments
- plot
A ggformula/ggplot object, typically created with
gf_point().- fun
A function that takes a numeric vector x and returns predicted y.
- linewidth
Numeric width of the residual lines. Default
0.2.- ...
Additional aesthetics passed to
ggplot2::geom_segment(), e.g.,color,alpha,linetype.
Details
Draws vertical residual lines from observed points to predicted values
computed by a user-supplied function of x (e.g., the function plotted with
gf_function()).
Examples
set.seed(1)
df <- data.frame(X = 1:10, Y = 2 + 3 * (1:10) + rnorm(10))
my_fun <- function(x) 2 + 3 * x
gf_point(Y ~ X, data = df) %>%
gf_function(my_fun) %>%
gf_resid_fun(my_fun, color = "red", alpha = 0.5)