R/test_fit.R
split_data.Rd
Split data into train and test sets.
split_data(data, prop = 0.7)
A data frame.
The proportion of rows to assign to the training set.
A list with two data frames, train and test.
train
test